#
# spec file for package liblouis
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           liblouis
Version:        3.3.0
Release:        lp150.2.5
Summary:        Two-way braille translator
License:        LGPL-3.0+
Group:          Productivity/Other
Url:            http://liblouis.org/
Source0:        https://github.com/liblouis/liblouis/releases/download/v%{version}/liblouis-%{version}.tar.gz
BuildRequires:  pkg-config
PreReq:         %install_info_prereq
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3
Requires:       liblouis14 = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
liblouis is a translator from and to braille. It features support for
computer and literary braille, supports contracted and uncontracted
translation for many languages and has support for hyphenation. New
languages can be added through tables that support a rule- or
dictionary-based approach. Math braille (Nemeth and Marburg) is
supported.

Included are also tools for testing and debugging tables.

%package -n liblouis14
Summary:        Two-way braille translator
# We used to have a package named liblouis, until 2.4.1.
License:        LGPL-3.0+
Group:          System/Libraries
Requires:       %{name}-data >= %{version}
Provides:       %{name} = %{version}
Obsoletes:      %{name} < %{version}

%description -n liblouis14
liblouis is a translator from and to braille. It features support for
computer and literary braille, supports contracted and uncontracted
translation for many languages and has support for hyphenation. New
languages can be added through tables that support a rule- or
dictionary-based approach. Math braille (Nemeth and Marburg) is
supported.

%package data
Summary:        Data files for the liblouis two-way braille translator
License:        LGPL-3.0+
Group:          System/Libraries
Conflicts:      liblouis2 < 3.3.0

%description data
liblouis is a translator from and to braille. It features support for
computer and literary braille, supports contracted and uncontracted
translation for many languages and has support for hyphenation.

This package contains data required by main package.

%package tools
Summary:        Tools from the liblouis braille translator package
License:        GPL-3.0+
Group:          Productivity/Other

%description tools
liblouis is a translator from and to braille. It features support for
computer and literary braille, supports contracted and uncontracted
translation for many languages and has support for hyphenation.

%package doc
Summary:        Documentation for the liblouis braille translator
License:        LGPL-3.0+
Group:          Documentation/Other

%description doc
liblouis is a translator from and to braille. It features support for
computer and literary braille, supports contracted and uncontracted
translation for many languages and has support for hyphenation.

%package devel
Summary:        Development files for the liblouis braille translator
License:        LGPL-3.0+
Group:          Development/Libraries/C and C++
Requires:       liblouis14 = %{version}

%description devel
liblouis is a translator from and to braille. It features support for
computer and literary braille, supports contracted and uncontracted
translation for many languages and has support for hyphenation. New
languages can be added through tables that support a rule- or
dictionary-based approach. Math braille (Nemeth and Marburg) is
supported.

%package -n python3-louis
Summary:        Python3 bindings for the liblouis braille translator
License:        LGPL-3.0+
Group:          Development/Languages/Python
Requires:       liblouis14 = %{version}

%description -n python3-louis
liblouis is a translator from and to braille. It features support for
computer and literary braille, supports contracted and uncontracted
translation for many languages and has support for hyphenation.

This subpackage contains the Python3 bindings.

%prep
%setup

%build
%configure --disable-static --enable-ucs4
# TODO: fix Makefile so that -j1 isn't needed
make -j1

# build python binding
pushd python
%python3_build
popd

%install
%make_install
# doc is only auto-installed when makeinfo is present
%make_install -C doc
find %{buildroot} -type f -name "*.la" -delete -print
# We'll package them as rpm docs
%{__rm} -f %{buildroot}%{_datadir}/doc/liblouis/liblouis.{html,txt}
%fdupes %{buildroot}%{_datadir}
%fdupes %{buildroot}%{_libdir}

# install python binding
pushd python
%python3_install
popd

%post doc
%install_info --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%preun doc
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%post -n liblouis14 -p /sbin/ldconfig

%postun -n liblouis14 -p /sbin/ldconfig

%files -n liblouis14
%defattr(-, root, root)
%doc AUTHORS ChangeLog COPYING.LESSER NEWS README
%{_libdir}/*.so.*

%files data
%defattr(-, root, root)
%{_datadir}/liblouis/

%files tools
%defattr(-, root, root)
%doc COPYING
%{_bindir}/lou_*

%files doc
%defattr(-, root, root)
%doc doc/liblouis.html doc/liblouis.txt
%{_infodir}/%{name}.info.gz

%files devel
%defattr(-, root, root)
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_includedir}/liblouis

%files -n python3-louis
%defattr(-, root, root)
%{python3_sitelib}/louis*.egg-info
%{python3_sitelib}/louis

%changelog
* Tue Oct  3 2017 jengelh@inai.de
- Redo package summaries, and compact/trim descriptions for size.
* Mon Oct  2 2017 jmatejek@suse.com
- drop separate spec files for python-louis and python3-louis
- completely drop python2 bindings
- build python3-louis as a subpackage of liblouis
* Wed Sep  6 2017 mgorse@suse.com
- Update to version 3.3.0:
  + New features
  - A new tool ~lou_maketable~ enables the creation of tables
    based on a corpus of known good Braille translations. This
    has huge potential to simplify table maintenance for tables
    that have so far been dominated by large exception lists.
  - A new API and a corresponding command line tool to query
    table meta data
  + UEB Grade 2:
  - Fix back-translation of whole word contractions followed
    by other contractions
    + Fix back-translation for contractions followed by
    punctuation
  + Security
  - Fix a number of CVEs (illegal address access, buffer
    overflow and use-after-free: boo#1056105 (CVE-2017-13738),
    boo#1056101 (CVE-2017-13739), boo#1056097 (CVE-2017-13740),
    boo#1056095 (CVE-2017-13741), boo#1056093 (CVE-2017-13742),
    boo#1056090 (CVE-2017-13743), and boo#1056088
    (CVE-2017-13744)
  + Braille table improvements
- Changes from version 3.2.0:
  + Bug fixes
  - Fix capsnocont opcode. Also mark capital letters with
    capsletter symbol when capsnocont is defined but no
    begcapsword indicator is defined.
  - Fix the syllable opcode. It had been broken under some
    circumstances since 3.0.
  + Other changes
    + Fix building of Python bindings when cross-compiling.
  - lou_checkyaml is now only installed if libyaml is available.
  - Enhance documentation on usage of display tables in
    particular
  in conjunction with Unicode dot patterns.
  + Braille table improvements
- Changes from version 3.1.0:
  + New features:
  - Most of the translation tables now contain meta data. This
    makes them discoverable. Programs can use the lou_findTable
    function to find a table based on a query.
  - Add a noUndefinedDots mode to disable the output of dot
    numbers when back-translating undefined patterns.
  - When back translating input from a braille keyboard cell by
    cell, it is desirable to output characters as soon as they
    are produced.  Similarly, when back translating contracted
    braille, it is desirable to provide a "guess" to the user of
    the characters they typed. To achieve this, liblouis needs to
    have the ability to produce no text when indicators (which
    don't produce a character by themselves) are not followed by
    another cell. This works already for indicators liblouis
    knows about such as capital sign, number sign, etc., but it
    does not work for indicators which are not (and cannot be)
    specifically defined as indicators. For example, in UEB, dots
    4 5 6 alone produces the text "\456/". Setting the
    noUndefinedDots mode suppresses this dot number output.
  - Add a partialTrans mode to specify that back-translation
    input should be treated as an incomplete word. If this mode
    is set, rules that apply only for complete words or at the
    end of a word will not take effect. This is intended to be
    used when translating input typed on a braille keyboard to
    provide a rough idea to the user of the characters they are
    typing before the word is complete.
  + Bug fixes
  - - Fixes implicit declaration of 'pattern_check'
  - Fix a stackoverflow crash on applications with smaller stack
    size.
  - Fix the \v escape sequence.
  - The Python bindings now give a helpful error if liblouis has
    been compiled with a different character size than Python.
  - Massive bug fixes in multipass rules. Dave Mielke has done a
    tremendous job improving the multipass machinery also in the
    context of back-translation. Where needed nofor/noback has
    been added to the multipass rules.
  + Other changes
  - Improvements to the Emacs mode for editing liblouis tables
  - Documenting lou_charSize
  + Braille table improvements
  + License changes
  - DocArch has agreed to re-license their tables, so we have 8
    more tables under the LGPLv2.1+.
- Changes from version 3.0.0:
  + New features
  - Numerous features to support UEB properly.
  - support the many emphasis classes needed for UEB.
  - support translation of numbers according to the rules of UEB.
  - Capitalization is now handled just like emphasis.
  - support for numeric mode
  - UTF-8 support for all tools
  - Add ~lou_checkTable~ and ~lou_getTypeformForEmphClass~ to
    the C API and to the Python bindings
  + Bug fixes
  - Stop buffer overrun in ~lou_getProgramPath~, and also free
    memory after usage.
  + Other changes
  - The license of the library and most of the tables has been
    changed to LGPLv2.1+.
  + Braille table improvements
  * Changes from version 2.6.5:
  + New features
  - lou_trace supports backtranslation now.
  + Bug fixes
  - Fix a bug in the findtable code.
  - Fixes to the logging code
  + Other changes
  - Clean up dead code i.e. remove support for (undocumented)
    nobreak opcode.
  + Braille table improvements
- Use %%{version} in Source
- Pass --enable-ucs4 to configure, for compatibility with python
- Build with make -j1; otherwise make is unable to resolve some
  dependencies.
* Fri Feb 10 2017 dimstar@opensuse.org
- Define python_sitelib: newer versions of python-rpm-macros
  overwrite it to be python2 specific (python3 macros is called
  python3_sitelib).
- To be on the safe side, define __python to python2 when not
  building for python3.
* Mon Jun  6 2016 dimstar@opensuse.org
- Move %%install_info_delete from postun to preun.
- Drop makeinfo BuildRequires: it's quite a big dependency and
  the .info file is present in the tarball.
- Install doc directly (make_install -C doc).
* Thu Apr 14 2016 mgorse@suse.com
- Update to GNOME 3.20  Fate#318572
* Tue Jan 19 2016 jengelh@inai.de
- Use %%{?_smp_mflags} for parallel build, newer %%make_install
  for installation, and remove redundant %%clean section.
* Mon Jan 11 2016 fcrozat@suse.com
- Move data from library package to separate subpackage, to ensure
  library package can be safely upgraded.
* Wed Oct 21 2015 zaitor@opensuse.org
- Update to version 2.6.4:
  + New features: YAML based harness tests. Harness tests can now
    be written in simple YAML notation and they are integrated with
    the normal `make check' command. They can be used for both ucs2
    and ucs4 and no Python is required.
  + Bug fixes:
  - Use a separate gnulib instance for the library and the tools.
    Use the strndup module to avoid build problems on windows.
  - Fix a problem with the nocross opcode when used in
    combination with the opcodes nocont and compbrl.
  - Fix a problem with the decoding of the harness test files.
  - Fix numerous problems in the way braille indicators are
    handled. There is now a safe version of the checkAttr
    function which makes sure that no attributes are checked
    beyond the boundaries of the currentInput. This fixes the
    random behavior with tests where the emphasis extends to the
    end of the input string.
  + Other changes:
  - If found use texi2any to build the documentation.
  - Fix permissions of Korean tables.
  - Update the windows build instructions.
  + Braille table improvements:
- Changes from version 2.6.3:
  + New features:
  - [beta] The new function lou_findTable can be used for table
    discovery based on meta data in table headers.
  - The Python API now has a new function to check tables aptly
    named ~checkTable~.
  + Bug fixes: Fixed a problem in resolveTable when using a Java
    resolver.
  + Other changes: The build dependency on makeinfo is now
    optional. If it is not installed we simply do not build the
    documentation.
  + Braille table improvements.
  + Corrections and improvements made to UEB tables.
- Changes from version 2.6.2:
  + New features: Harness tests now can test for typeform
    differences.
  + Bug fixes: Fix for emphasis bug.
  + Braille table improvements.
- Changes from version 2.6.1:
  + New features: New Braille tables.
  + Braille table improvements.
  + Bug fixes: Fix a compiler warning in the logging code.
  + Documentation updates: The documentation has been restructured
    to be more beginner friendly and a short introduction to
    translation table writing has been added.
  + Other changes:
  - When compiling with mingw or cygwin resulting dll is
    liblouis.dll.
  - runHarness.py: add new output format, compact output mode
    suitable for grepping.
  + Backwards incompatible changes:
  - Deleted ga.ctb now superseded by ga-g1.utb and ga.g2.ctb.
  - Nl-Nl-g1.utb has been removed. It is superseded by
    nl-NL-g1.ctb.
  - nl-be-g1.utb has been removed. It is superseded by
    nl-BE-g1.ctb.
- Changes from version 2.6.0:
  + New features:
  - New Braille tables.
  - Logging callback. There is now a callback system in place to
    get error messages and warnings.
  + Bug fixes:
  - Fix back translation problems when word gets split in unusual
    places causing back translation of whole words.
  - Fixed bug to prevent removal of \xffff between largesign
    rules.
  - Fixed a bug in back translation, when a letsign was
    encountered, the letsign was being applied beyond the element
    it applied to.
  - Fix memory leaks in the default table resolver introduced in
    the previous release.
  - Fixes to the build system.
  + Braille table improvements.
- Bump soname following upstream changes, leading to rename of
  package liblouis2 to liblouis9.
- Update url and sourceurl to new working ones.
- Add exlicit makeinfo BuildRequires, we want to build
  documentation.
* Thu Mar 27 2014 mgorse@suse.com
-Update to version 2.5.4:
  + New features
  - Added function lou_registerTableResolver for plugging in a
    table resolver callback from your host language.
  + Bug Fixes
  - Fixed ENDSEGMENT indicator in computer Braille.
  - Emphasized words should now be contracted consistently.
  - Fixed several problems with back-translation. A slash within
    a number and strings such as 5-inch-diameter and
    25-year-old-man should now back-translate correctly.
  - Fixed a problem with syllable opcode.
  - Fix warnings with gcc 4.8.2.
  - When a table is specified with an absolute or relative path,
    the "includes" in that table will now work as expected,
    meaning files in the same directory will be found.
  + Braille Table Improvements to fr-bfu-comp8, en-us-g2,
    en-ueb-g2, BUlgarian, en-gb-g1, Nemeth, Slovenian, Norwegian,
    Nepali, Danish.
  + Backwards incompatible changes
  - Delete the table chardefs-ueb.cti as these rules are now
    provided by en-ueb-chardefs.uti
- Update source URL.
- COPYING.LIB has been renamed to COPYING.LESSER
- Use fdupes for base package.
* Sat Jun 22 2013 zaitor@opensuse.org
- Update to version 2.5.3:
  + New features:
  - New Braille tables.
    . Korean grade 1 and grade 2.
    . U.K. English 8 dot computer braille table.
    . New Russian literary and computer braille tables. These
    replace the older Russian tables which are left for
    backwards compatibility.
    . New hyphenation dictionary for Russian.
    . Updated hyphenation tables for the Norwegian language
    (nynorsk and bokmål).
    . New hyphenation dictionary for Esperanto.
    . New Esperanto grade 1 table, using the x system for
    accented letters.
  - runHarness.py:
    . Accept filename globs on the commandline to run specific
    harness files. In tests/harness, one can do make <filename>
    or make runall Removed from make check because these checks
    are checking the validity of our tables, rather than
    validity of the code.
  + Braille Table Improvements:
  - da-dk-g2.ctb, mostly rewritten to use nocross and hyphenation
    table.
  - Most tables: removed the default collapse whitespace
    statements, if you need to compress whitespace, consider
    adding compress.ctb to the list of tables when processing.
  - Corrections to Unified English Braille Code (Grade 1 and 2).
  - Corrections to apostrophes in the Computer Spanish 8 dots
    Braille table (Es-Es-G0.utb).
  - Corrections for double angle quotation marks and emphasis
    marks in the Norwegian Grade 0 Braille Table.
  - Fixes for a minor problem regarding the noletsign in
    Norwegian contracted braille.
  - Corrections to the Italian table.
  - Corrections to the Hungarian grade 1 table.
  - Corrections to English, U.S. Grade 2 (ABAE) table.
  - Further reorganization of the tables to remove duplication.
    Move litdigit opcode common parts and include where needed.
  - Removed obsolete en-us-g1.utb, which has been replaced by
    en-us-g1.ctb.
  - Added dictionary harness tests for: en-ueb-g2.ctb,
    en-us-g2.ctb.
  - Corrections to Nemeth character definitions.
  - Corrections to the Esperanto table.
  + Bug Fixes:
  - Cursor position calculation is now based on the same code
    that calculates inpos and outpos. This probably solves a
    number of bugs.
  - Fix nocross opcode processing.
  - Fix several buffer over/under runs in
    lou_translateString.c:hyphenate.
  - Fix the '=' problem, i.e. fix inputPositions calculation for
    the case where the equals sign is used as the dots operand.
  - Fix a bug when resizing a table. Previously not all
    references to this table were updated.
  + Backwards incompatible changes:
  - The feature that allowed a mapping between language code and
    Braille table was removed as it contained a out-of-bounds
    access bug, was never documented and probably never used.
* Sat Jan 12 2013 dimstar@opensuse.org
- Add python3-louis target.
* Sun Dec 23 2012 zaitor@opensuse.org
- Update to version 2.5.2:
  + New features:
  - New tool to trace rule application (lou_trace).
  - New Braille tables
    . Inuktitut grade 1.
    . UEB grade 1 and 2.
    . Korean table.
  - Braille Table Improvements
  - da-gk-g2.ctb, fixes for transposed â, å, æ, ä, ø  and ö,
    corrected/improved harness tests.
  - Corrections for en-GB-g2.ctb.
  - Corrections to the Hungarian grade 1 table.
  + Bug Fixes:
  - Update gnulib.
  - Fix a bug in the correct opcode which causes sometimes random
    results when translating.
  - Fixes for compiler warnings.
  - Fix some Valgrind warnings about invalid reads.
* Tue Sep 25 2012 dimstar@opensuse.org
- Update to version 2.5.1:
  + Braille Table Improvements
  - Fix encoding problem in italian table and added more
    character definitions.
  - Rename it-it-g1.utb to it-it-comp6.utb and it-it-g1.utb2 to
    it-it-comp8.utb.
  + Bug fixes:
  - Fix outputPos and inlen where an input character generates
    multiple output characters.
* Mon Sep 17 2012 dimstar@opensuse.org
- Update to version 2.5.0:
  + New features:
  - New Braille tables
    . Estonian grade 0
    . Portuguese 8 dot Computer braille
  - UTF-8 support in tables
  - Improvements to the python bindings
  - Add a doctest infrastructure
  - Support for Python 3 in the Python bindings
  + Improved C-based test framework
  + Improved documentation
  + Braille table improvements
  + Bug fixes
- Remove checks for outdated openSUSE versions (<= 11.2).
* Mon Sep 10 2012 vuntz@opensuse.org
- Create a tools and a doc subpackages to contain the tools and
  documentation shipped by liblouis, instead of having a liblouis
  subpackage, since that's confusing (because what people are
  usually interested is the liblouis2 subpackage).
- Ship COPYING.LIB in liblouis2 subpackage and COPYING in the tools
  subpackage since everything is LGPL-3.0+, except the tools that
  are GPL-3.0+. That fixes bnc#779253.
- Since we don't have a liblouis subpackage anymore, add Provides
  and Obsoletes for it to liblouis2 for smooth upgrades.
* Fri Feb 24 2012 vuntz@opensuse.org
- Update to version 2.4.1:
  + New features:
  - Czech hyphenation table
  - Spanish grade 1 table
  - New tamil table
  + Braille Table Improvements: Icelandic 8-dot, Norwegian,
    Portuguese grade1, uncontracted Spanish.
- Changes from version 2.4.0:
  + New features:
  - New Generic Farsi Grade 1 table
  - Emacs mode for editing Braille tables
  + Braille Table Improvements: Czech, French comp6 and comp8,
    Generic Arabic Grade 1, Romanian.
* Sun May 22 2011 dimstar@opensuse.org
- Update to version 2.3.0:
  + New features:
  - Multiple table search path (with LOUIS_TABLEPATH environment
    variable)
  - New --quiet option for lou_checktable
  - New functions to make libraries relocatable
  - New Braille tables: Swedish, Sorani (Kurdish), Ethiopic,
    Serbian, many Indian languages , Icelandic 6- and 8-dot,
    Catalan, Dutch Braille (for Belgium and the Netherlands),
    Flemish Braille Math Code (a.k.a. Woluwe code).
  + Braille Table Improvements: Chinse, Spanish Braille, French 6
    and 8 dot, Italian 8 dot, Generic Arabic Grade 1, Spanish,
    Norwegian.
  + Bug fixes:
  - Fixed a long standing bug with an infinite loop in the table
    compiler
  + Improved documentation
- Add pkg-config BuildRequires to get proper pkgconfig() provides.
* Sat Aug 28 2010 vuntz@opensuse.org
- Update to version 2.1.1:
  + Bug fixes:
  - Fixed problems with the Danish grade 2 table
  - Fixed problems with the Marburg maths table for mathematics
    and the UK maths table for mathematics
- Changes from version 2.1.0:
  + New features:
  - New tables:
    . Added tables for Portuguese grade 1 and 2
    . Added unicode.dis for Unicode braille
  - Modified tables: Updated Danish tables
  - Implemented language to table mapping
  - New format of error messages: the error messages are now
    reported in a format similar to the one used in gcc.
  - New opcode: added undefined opcode
  - Python bindings:
    . Allow the user to configure the maximum output length by
    specifying a number by which the input length is multiplied
    using the outlenMultiplier module variable.
    . Add compbrlLeftCursor mode constant.
    . Add compileString function which wraps lou_compileString.
    . Corrections/clarifications to docstrings.
    . Add python binding for the lou_hyphenate function.
    . Added python wrapper for lou_backTranslateString and
    lou_backTranslate.
  - Add liblouisxslt as an example to python/examples.
  - Add compbrlLeftCursor.
  + Bug fixes:
  - Fix the output cursorPos when the compbrlAtCursor mode is
    enabled and the characters around the cursor translate to
    multiple braille cells, such as in the Chinese braille
    tables.
  - Fix outpos when doing back translation
  - Fix the input/output position arrays for characters in the
    input which are undefined in the translation table.
  - Table fixes:
    . Fixed a bug with back translation of '*n'.
    . Fixes to the en-us-g2.ctb table
  - Python bindings:
    . Remove unnecessary imports, allowing the bindings to run in
    Python 2.7.
    . lou_translate* writes output information in typeform, so
    allocate enough bytes for it. Fixes possible buffer
    overruns and resultant crashes.
  - Miscellaneous:
    . Fixes to the man page generation to fix issues
    . Do not invoke help2man when cross-compiling
    . Documentation updates (issue 10)
    . Removing noletsign defaults
    . Many small fixes
- Changes from version 2.0.0:
  + New function: Adding lou_charSize function
- Changes from version 1.9.0:
  + New functions:
  - lou_dotsToChar and lou_charToDots function
  - Added lou_compileString for adding entries to tables at
    run-time.
* Wed Dec  2 2009 vuntz@opensuse.org
- Update to version 1.8.0:
  + This release contains a number of improvements notably the
    integrationof gnulib, the automatic generation of man pages and
    the addition of tables for German grade 2.
  + New features
  - New tables
    . Tables German Grade 2
    . Swiss German
  - Modified tables
    . Updated Norwegian tables
  - man pages
    . All tools accept the --version and --help options and are
    documented in man pages
  - Corpus based test cases for tables
  + Bug fixes
  - Many small fixes
- Rename liblouis0 subpackage to liblouis2, because of soname bump.
* Fri Aug 28 2009 vuntz@novell.com
- Fix python-louis build: with the new upstream release, we now
  need to build the library before building the python bindings.
* Fri Aug 21 2009 captain.magnus@opensuse.org
- Update to version 1.7.0:
  + The main new feature of this release is the support for UK and
    Marburg math. Other changes include a new tool to check
    hyphenation and the usual improvement and addition of tables.
    Also The test suite has been enhanced and finally passes
  + Fix for library name and Python bindings
  + Documentation fixes
  + Many small fixes
- Remove liblouis-build-fix.patch. Fixed upstream
- Remove liblouis-dlopen-versioned.patch. Code changed
* Fri Aug 21 2009 vuntz@novell.com
- Add liblouis-dlopen-versioned.patch to have the python bindings
  open the versioned .so library, so that they don't require the
  devel package.
- Make python-louis require liblouis0.
* Thu Aug 13 2009 vuntz@novell.com
- Use python_sitelib instead of py_sitedir.
* Thu Jul 30 2009 vuntz@novell.com
- Initial package.
